@@ -337,7 +337,7 @@ class AutoscalingClient(AbstractClient):
 
 
     def DeleteAutoScalingGroup(self, request):
-        """This API (DeleteAutoScalingGroup) is used to delete the specified auto scaling group that has no instances and remains inactive.
+        """This API is used to delete an auto-scaling group. Make sure that there are no `IN_SERVICE` instances in the group, and there are no ongoing scaling activities. When you delete a scaling group, instances in the status of `CREATION_FAILED`, `TERMINATION_FAILED` and `DETACH_FAILED` are not terminated.
 
         :param request: Request instance for DeleteAutoScalingGroup.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.DeleteAutoScalingGroupRequest`
@@ -1153,11 +1153,12 @@ class AutoscalingClient(AbstractClient):
 
 
     def ScaleOutInstances(self, request):
-        """This API is used to add the specified number of instances to the scaling group, which returns the scaling activity ID `ActivityId`.
-        * There is no on going scaling task.
+        """This API is used to add the specified number of instances to a scaling group. It returns the scaling activity ID `ActivityId`.
+        * u200dMake sure that there are no ongoing scaling tasks.
         * This API is valid even when the scaling group is disabled. For more details, see [DisableAutoScalingGroup](https://intl.cloud.tencent.com/document/api/377/20435?from_cn_redirect=1).
-        * The desired capacity will be increased accordingly. The new desired capacity should be no more than the maximum capacity.
-        * If the scale-out activity failed or partially succeeded, the final desired capacity only includes the instances that have been added successfully.
+        * The total number of instances after this action cannot exceed the maximum capacity.
+        * If a scale-out action failed or partially succeeded, only the number of successfully created instances is added to the number of desired capacity.
+        * If the allocation policy is `SPOT_MIXED`, there may be multiple scaling activities triggered for one scaling task. u200dIn this case, the first activity ID (`ActivityId`) is returned.
 
         :param request: Request instance for ScaleOutInstances.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.ScaleOutInstancesRequest`
