@@ -236,6 +236,9 @@ INVALIDPARAMETERVALUE_LIFECYCLEHOOKNAMEDUPLICATED = 'InvalidParameterValue.Lifec
 # The value exceeds the limit.
 INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
 
+# Target group listeners are not supported.
+INVALIDPARAMETERVALUE_LISTENERTARGETTYPENOTSUPPORTED = 'InvalidParameterValue.ListenerTargetTypeNotSupported'
+
 # The bandwidth package ID is required.
 INVALIDPARAMETERVALUE_MISSINGBANDWIDTHPACKAGEID = 'InvalidParameterValue.MissingBandwidthPackageId'
 
@@ -488,5 +491,8 @@ RESOURCEUNAVAILABLE_TDMQCMQTOPICHASNOSUBSCRIBER = 'ResourceUnavailable.TDMQCMQTo
 # The specified availability zone is unavailable.
 RESOURCEUNAVAILABLE_ZONEUNAVAILABLE = 'ResourceUnavailable.ZoneUnavailable'
 
+# You have not assigned the CAM role AS-QCSRole to Auto Scaling. Please go to the AS console to complete authorization first.
+UNAUTHORIZEDOPERATION_AUTOSCALINGROLEUNAUTHORIZED = 'UnauthorizedOperation.AutoScalingRoleUnauthorized'
+
 # Unsupported operation.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
