@@ -71,9 +71,15 @@ FAILEDOPERATION_GETPRIVILEGEERROR = 'FailedOperation.GetPrivilegeError'
 # Query failed.
 FAILEDOPERATION_INSTANCEQUERYERROR = 'FailedOperation.InstanceQueryError'
 
+# 
+FAILEDOPERATION_INSTANCETASKCONFLICTERROR = 'FailedOperation.InstanceTaskConflictError'
+
 # Failed to deserialize JSON.
 FAILEDOPERATION_JSONUNMARSHALERROR = 'FailedOperation.JsonUnmarshalError'
 
+# No policy modification detected
+FAILEDOPERATION_NOTCHANGESTRATEGY = 'FailedOperation.NotChangeStrategy'
+
 # It is not a read-only instance with delayed replication enabled.
 FAILEDOPERATION_NOTDELAYRO = 'FailedOperation.NotDelayRo'
 
@@ -86,15 +92,24 @@ FAILEDOPERATION_PRIVILEGEDATAILLEGAL = 'FailedOperation.PrivilegeDataIllegal'
 # Database proxy in an exceptional status.
 FAILEDOPERATION_PROXYGROUPSTATUSERROR = 'FailedOperation.ProxyGroupStatusError'
 
+# Failed to query the audit task
+FAILEDOPERATION_QUERYAUDITTASKFAILERROR = 'FailedOperation.QueryAuditTaskFailError'
+
 # Log query failed.
 FAILEDOPERATION_QUERYLOGERROR = 'FailedOperation.QueryLogError'
 
+# Cross-region deserialization failed for the high-availability service.
+FAILEDOPERATION_REMOTECALLUNMARSHALERROR = 'FailedOperation.RemoteCallUnmarshalError'
+
 # The proxy is being created or already exists. You cannot create it again.
 FAILEDOPERATION_REPEATCREATEPROXYERROR = 'FailedOperation.RepeatCreateProxyError'
 
 # Exception with the backend request for the service. Please contact customer service.
 FAILEDOPERATION_RESPONSEVALUEERROR = 'FailedOperation.ResponseValueError'
 
+# 
+FAILEDOPERATION_RESULTSETOVERLIMIT = 'FailedOperation.ResultSetOverLimit'
+
 # Failed to initiate the operation. Please try again later. If the operation remains unsuccessful, please contact customer service.
 FAILEDOPERATION_STARTFLOWERROR = 'FailedOperation.StartFlowError'
 
@@ -113,6 +128,9 @@ FAILEDOPERATION_TYPEINCONFLICT = 'FailedOperation.TypeInConflict'
 # The IP has been occupied.
 FAILEDOPERATION_VPCIPINUSEERROR = 'FailedOperation.VpcIpInUseError'
 
+# 
+FAILEDOPERATION_VPCIPINVALIDERROR = 'FailedOperation.VpcIpInvalidError'
+
 # The IP doesn’t exist in the subnet.
 FAILEDOPERATION_VPCIPNOTINSUBNETERROR = 'FailedOperation.VpcIpNotInSubnetError'
 
@@ -122,6 +140,9 @@ INTERNALERROR = 'InternalError'
 # An error occurred while querying async tasks.
 INTERNALERROR_ASYNCREQUESTERROR = 'InternalError.AsyncRequestError'
 
+# Failed to query the audit log
+INTERNALERROR_AUDITDESCRIBELOGERROR = 'InternalError.AuditDescribeLogError'
+
 # An error occurred in the internal service of the audit service.
 INTERNALERROR_AUDITERROR = 'InternalError.AuditError'
 
@@ -176,6 +197,9 @@ INTERNALERROR_FTPERROR = 'InternalError.FtpError'
 # Exceptional HTTP request
 INTERNALERROR_HTTPERROR = 'InternalError.HttpError'
 
+# 
+INTERNALERROR_HTTPREQUESTERROR = 'InternalError.HttpRequestError'
+
 # Import failed
 INTERNALERROR_IMPORTERROR = 'InternalError.ImportError'
 
@@ -443,6 +467,15 @@ OPERATIONDENIED_PROXYNODECOUNTLIMITERROR = 'OperationDenied.ProxyNodeCountLimitE
 # This operation is not allowed during database proxy upgrade task.
 OPERATIONDENIED_PROXYUPGRADETASKSTATUSERROR = 'OperationDenied.ProxyUpgradeTaskStatusError'
 
+# Failed to query the audit log
+OPERATIONDENIED_QUERYAUDITLOGSERROR = 'OperationDenied.QueryAuditLogsError'
+
+# The resource was not found.
+OPERATIONDENIED_RESOURCENOTFOUNDERROR = 'OperationDenied.ResourceNotFoundError'
+
+# The resource was not found.
+OPERATIONDENIED_RESOURCENOTFUNDERROR = 'OperationDenied.ResourceNotFundError'
+
 # The maximum number of results has been reached. Please narrow down your query.
 OPERATIONDENIED_RESULTOVERLIMIT = 'OperationDenied.ResultOverLimit'
 
@@ -497,5 +530,8 @@ UNAUTHORIZEDOPERATION_NOTENOUGHPRIVILEGES = 'UnauthorizedOperation.NotEnoughPriv
 # Unsupported operation.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
+# The current operation is not supported for instances with no resource usage limit.
+UNSUPPORTEDOPERATION_NOTSUPPORTNORMALINSTANCE = 'UnsupportedOperation.NotSupportNormalInstance'
+
 # Unsupported permission.
 UNSUPPORTEDOPERATION_PRIVILEGESUNSUPPORTEDERROR = 'UnsupportedOperation.PrivilegesUnsupportedError'
