@@ -46,7 +46,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ApplyConfigToMachineGroup(self, request):
@@ -69,7 +69,30 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CheckRechargeKafkaServer(self, request):
+        """This API is used to check whether the Kafka service cluster is accessible.
+
+        :param request: Request instance for CheckRechargeKafkaServer.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CheckRechargeKafkaServerRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CheckRechargeKafkaServerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CheckRechargeKafkaServer", params, headers=headers)
+            response = json.loads(body)
+            model = models.CheckRechargeKafkaServerResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CloseKafkaConsumer(self, request):
@@ -92,7 +115,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateAlarm(self, request):
@@ -115,7 +138,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateAlarmNotice(self, request):
@@ -138,7 +161,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateConfig(self, request):
@@ -161,7 +184,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateConsumer(self, request):
@@ -184,7 +207,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateCosRecharge(self, request):
@@ -207,7 +230,30 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateDataTransform(self, request):
+        """This API is used to create a data processing task.
+
+        :param request: Request instance for CreateDataTransform.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateDataTransformRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateDataTransformResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDataTransform", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateDataTransformResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateExport(self, request):
@@ -230,7 +276,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateIndex(self, request):
@@ -253,7 +299,30 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateKafkaRecharge(self, request):
+        """This API is used to create a Kafka data subscription task.
+
+        :param request: Request instance for CreateKafkaRecharge.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateKafkaRechargeRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateKafkaRechargeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateKafkaRecharge", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateKafkaRechargeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateLogset(self, request):
@@ -276,7 +345,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateMachineGroup(self, request):
@@ -299,7 +368,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateShipper(self, request):
@@ -322,7 +391,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateTopic(self, request):
@@ -345,7 +414,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteAlarm(self, request):
@@ -368,7 +437,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteAlarmNotice(self, request):
@@ -391,7 +460,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteConfig(self, request):
@@ -414,7 +483,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteConfigFromMachineGroup(self, request):
@@ -437,7 +506,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteConsumer(self, request):
@@ -460,7 +529,30 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteDataTransform(self, request):
+        """This API is used to delete a data processing task.
+
+        :param request: Request instance for DeleteDataTransform.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteDataTransformRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteDataTransformResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteDataTransform", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteDataTransformResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteExport(self, request):
@@ -483,7 +575,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteIndex(self, request):
@@ -506,7 +598,30 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteKafkaRecharge(self, request):
+        """This API is used to delete a Kafka data subscription task.
+
+        :param request: Request instance for DeleteKafkaRecharge.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteKafkaRechargeRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteKafkaRechargeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteKafkaRecharge", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteKafkaRechargeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteLogset(self, request):
@@ -529,7 +644,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteMachineGroup(self, request):
@@ -552,7 +667,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteMachineGroupInfo(self, request):
@@ -575,11 +690,11 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteShipper(self, request):
-        """This API is used to delete a shipping rule.
+        """This API is used to delete a COS shipping task.
 
         :param request: Request instance for DeleteShipper.
         :type request: :class:`tencentcloud.cls.v20201016.models.DeleteShipperRequest`
@@ -598,7 +713,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteTopic(self, request):
@@ -621,7 +736,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAlarmNotices(self, request):
@@ -644,7 +759,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAlarms(self, request):
@@ -667,7 +782,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAlertRecordHistory(self, request):
@@ -690,7 +805,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeConfigMachineGroups(self, request):
@@ -713,7 +828,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeConfigs(self, request):
@@ -736,7 +851,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeConsumer(self, request):
@@ -759,7 +874,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCosRecharges(self, request):
@@ -782,7 +897,30 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeDataTransformInfo(self, request):
+        """This API is used to get the basic information of data processing tasks.
+
+        :param request: Request instance for DescribeDataTransformInfo.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeDataTransformInfoRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeDataTransformInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDataTransformInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDataTransformInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeExports(self, request):
@@ -805,7 +943,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeIndex(self, request):
@@ -828,7 +966,30 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeKafkaRecharges(self, request):
+        """This API is used to get the list of Kafka data subscription tasks.
+
+        :param request: Request instance for DescribeKafkaRecharges.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeKafkaRechargesRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeKafkaRechargesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeKafkaRecharges", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeKafkaRechargesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeLogContext(self, request):
@@ -851,7 +1012,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeLogHistogram(self, request):
@@ -874,7 +1035,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeLogsets(self, request):
@@ -897,7 +1058,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeMachineGroupConfigs(self, request):
@@ -920,7 +1081,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeMachineGroups(self, request):
@@ -943,7 +1104,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeMachines(self, request):
@@ -966,7 +1127,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribePartitions(self, request):
@@ -989,7 +1150,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeShipperTasks(self, request):
@@ -1012,7 +1173,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeShippers(self, request):
@@ -1035,7 +1196,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTopics(self, request):
@@ -1058,7 +1219,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetAlarmLog(self, request):
@@ -1081,7 +1242,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def MergePartition(self, request):
@@ -1104,7 +1265,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyAlarm(self, request):
@@ -1127,7 +1288,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyAlarmNotice(self, request):
@@ -1150,7 +1311,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyConfig(self, request):
@@ -1173,7 +1334,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyConsumer(self, request):
@@ -1196,7 +1357,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyCosRecharge(self, request):
@@ -1219,7 +1380,30 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyDataTransform(self, request):
+        """This API is used to modify a data processing task.
+
+        :param request: Request instance for ModifyDataTransform.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ModifyDataTransformRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ModifyDataTransformResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDataTransform", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyDataTransformResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyIndex(self, request):
@@ -1242,7 +1426,30 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyKafkaRecharge(self, request):
+        """This API is used to modify a Kafka data subscription task.
+
+        :param request: Request instance for ModifyKafkaRecharge.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ModifyKafkaRechargeRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ModifyKafkaRechargeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyKafkaRecharge", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyKafkaRechargeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyLogset(self, request):
@@ -1265,7 +1472,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyMachineGroup(self, request):
@@ -1288,7 +1495,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyShipper(self, request):
@@ -1311,7 +1518,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyTopic(self, request):
@@ -1334,7 +1541,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def OpenKafkaConsumer(self, request):
@@ -1357,7 +1564,30 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def PreviewKafkaRecharge(self, request):
+        """This API is used to preview the logs of Kafka data subscription tasks.
+
+        :param request: Request instance for PreviewKafkaRecharge.
+        :type request: :class:`tencentcloud.cls.v20201016.models.PreviewKafkaRechargeRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.PreviewKafkaRechargeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("PreviewKafkaRecharge", params, headers=headers)
+            response = json.loads(body)
+            model = models.PreviewKafkaRechargeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def RetryShipperTask(self, request):
@@ -1380,7 +1610,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def SearchLog(self, request):
@@ -1403,7 +1633,7 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def SplitPartition(self, request):
@@ -1426,14 +1656,14 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UploadLog(self, request, body):
         """## Note
-        To ensure log data reliability and help you use CLS more efficiently, we recommend you use the optimized API to upload logs. For more information about the API, see [Uploading Log via API](https://www.tencentcloud.com/document/product/614/50267).
+        To ensure log data reliability and help you use CLS more efficiently, we recommend you use the optimized API to upload logs. For more information about the API, see [Uploading Log via API](https://intl.cloud.tencent.com/document/product/614/16873?from_cn_redirect=1).
 
-        For the optimized API, we have developed an SDK (available in multiple languages) that provides features including async sending, resource control, automatic retry, graceful shutdown, and detection-based reporting. For details, see [Uploading Log via SDK](https://intl.cloud.tencent.com/document/product/614/45006).
+        For the optimized API, we have developed an SDK (available in multiple languages) that provides features including async sending, resource control, automatic retry, graceful shutdown, and detection-based reporting. For details, see [Uploading Log via SDK](https://intl.cloud.tencent.com/document/product/614/67157?from_cn_redirect=1).
 
         `UploadLog` allows you to synchronously upload log data. If you still want to continue to use this API instead of the optimized one, read this document.
 
@@ -1455,56 +1685,56 @@ class ClsClient(AbstractClient):
 
         #### Input parameters (pb binary streams in `body`)
 
-        | Parameter | Type | Location | Required | Description |
+        | Parameter       | Type    | Location | Required | Description                                                         |
         | ------------ | ------- | ---- | ---- | ------------------------------------------------------------ |
-        | logGroupList | message | pb    | Yes   | The `logGroup` list, which describes the encapsulated log groups. We recommend you enter up to five `logGroup` values.                     |
+        | logGroupList | message | pb   | Yes   | The `logGroup` list, which describes the encapsulated log groups. We recommend you enter up to five `logGroup` values. |
 
         `LogGroup` description:
 
-        | Parameter     | Required | Description                                                         |
+        | Parameter      | Required | Description                                                         |
         | ----------- | -------- | ------------------------------------------------------------ |
         | logs        | Yes       | Log array consisting of multiple `Log` values. The `Log` indicates a log, and a `LogGroup` can contain up to 10,000 `Log` values. |
-        | contextFlow | No       | Unique `LogGroup` ID, which should be passed in if the context feature needs to be used. Format: "{context ID}-{LogGroupID}". <br>Context ID: Uniquely identifies the context (a series of log files that are continuously scrolling or a series of logs that need to be sequenced), which is a 64-bit integer hex string. <br>LogGroupID: A 64-bit integer hex string that continuously increases, such as `102700A66102516A-59F59`.                        |
+        | contextFlow | No       | Unique `LogGroup` ID, which should be passed in if the context feature needs to be used. Format: "{Context ID}-{LogGroupID}". <br>Context ID: Uniquely identifies the context (a series of log files that are continuously scrolling or a series of logs that need to be sequenced), which is a 64-bit integer hex string. <br>LogGroupID: A 64-bit integer hex string that continuously increases, such as `102700A66102516A-59F59`.                        |
         | filename    | No       | Log filename                                                   |
         | source      | No       | Log source, which is generally the machine IP                           |
         | logTags     | No       | List of log tags                                               |
 
         `Log` description:
 
-        | Parameter | Required | Description |
+        | Parameter   | Required | Description                                                         |
         | -------- | -------- | ------------------------------------------------------------ |
-        | time | Yes | Unix timestamp of log time in seconds or milliseconds (recommended) |
-        | contents | No | Log content in key-value format. A log can contain multiple key-value pairs. |
+        | time     | Yes       | Unix timestamp of log time in seconds or milliseconds (recommended)      |
+        | contents | No       | Log content in key-value format. A log can contain multiple key-value pairs. |
 
         `Content` description:
 
-        | Parameter | Required | Description |
+        | Parameter | Required | Description                                                         |
         | ------ | -------- | ------------------------------------------------------------ |
         | key    | Yes       | Key of a field group in one log, which cannot start with `_`.                 |
         | value  | Yes       | Value of a field group. The `value` of one log cannot exceed 1 MB and the total `value` in `LogGroup` cannot exceed 5 MB. |
 
         `LogTag` description:
 
-        | Parameter     | Required | Description                                                         |
+        | Parameter | Required | Description                             |
         | ------ | -------- | -------------------------------- |
-        | key    | Yes       | Key of a custom tag             |
+        | key    | Yes       | Key of a custom tag                 |
         | value  | Yes       | Value corresponding to the custom tag key |
 
-        ## pb Compilation Sample
+        ## pb Compilation Example
 
-        This sample describes how to use the protoc compiler to compile the pb description file into a log upload API in C++.
+        This example shows you how to use the protoc compiler to compile a pb description file into a log upload API in C++.
 
         > ?Currently, protoc supports compilation in multiple programming languages such as Java, C++, and Python. For more information, see [protoc](https://github.com/protocolbuffers/protobuf).
 
         #### 1. Install Protocol Buffers
 
-        Download [Protocol Buffers](https://main.qcloudimg.com/raw/d7810aaf8b3073fbbc9d4049c21532aa/protobuf-2.6.1.tar.gz), decompress the package, and install the tool. The version used in the sample is protobuf 2.6.1 running on CentOS 7.3. Run the following command to decompress the `protobuf-2.6.1.tar.gz` package to the `/usr/local` directory and go to the directory:
+        Download [Protocol Buffers](https://main.qcloudimg.com/raw/d7810aaf8b3073fbbc9d4049c21532aa/protobuf-2.6.1.tar.gz), decompress the package, and install the tool. The version used in the example is protobuf 2.6.1 running on CentOS 7.3. Run the following command to decompress the `protobuf-2.6.1.tar.gz` package to the `/usr/local` directory and go to the directory:
 
         ```
         tar -zxvf protobuf-2.6.1.tar.gz -C /usr/local/ && cd /usr/local/protobuf-2.6.1
         ```
 
-        Run the following commands to start compilation and installation, and configure the environment variables:
+        Run the following commands to start compilation and installation and configure the environment variables:
 
         ```
         [root@VM_0_8_centos protobuf-2.6.1]# ./configure
@@ -1566,7 +1796,7 @@ class ClsClient(AbstractClient):
 
         #### 3. Compile and generate the API
 
-        This sample uses the proto compiler to generate a C++ file in the same directory as the `cls.proto` file. Run the following compilation command:
+        This example uses the proto compiler to generate a C++ file in the same directory as the `cls.proto` file. Run the following compilation command:
 
         ```
         protoc --cpp_out=./ ./cls.proto
@@ -1574,7 +1804,7 @@ class ClsClient(AbstractClient):
 
         > ?`--cpp_out=./` indicates that the file will be compiled in cpp format and output to the current directory. `./cls.proto` indicates the `cls.proto` description file in the current directory.
 
-        After the compilation succeeds, the code file in the corresponding programming language will be generated. This sample generates the `cls.pb.h` header file and [cls.pb.cc](http://cls.pb.cc) code implementation file as shown below:
+        After the compilation succeeds, the code file in the corresponding programming language will be generated. This example generates the `cls.pb.h` header file and [cls.pb.cc](http://cls.pb.cc) code implementation file as shown below:
 
         ```
         [root@VM_0_8_centos protobuf-2.6.1]# protoc --cpp_out=./ ./cls.proto
@@ -1602,4 +1832,4 @@ class ClsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
