@@ -101,6 +101,12 @@ INVALIDPARAMETER_CONFIGCONFLICT = 'InvalidParameter.ConfigConflict'
 # Invalid `Content`.
 INVALIDPARAMETER_CONTENT = 'InvalidParameter.Content'
 
+# There is a data processing task conflict.
+INVALIDPARAMETER_DATAFROMTASKCONFLICT = 'InvalidParameter.DataFromTaskConflict'
+
+# The data processing task does not exist.
+INVALIDPARAMETER_DATAFROMTASKNOTEXIST = 'InvalidParameter.DataFromTaskNotExist'
+
 # The unique key of database conflicts.
 INVALIDPARAMETER_DBDUPLICATION = 'InvalidParameter.DbDuplication'
 
@@ -113,6 +119,9 @@ INVALIDPARAMETER_INVALIDINDEXRULEFORSEARCHLOW = 'InvalidParameter.InValidIndexRu
 # An index rule already exists for the specified log topic.
 INVALIDPARAMETER_INDEXCONFLICT = 'InvalidParameter.IndexConflict'
 
+# The data processing statement is invalid.
+INVALIDPARAMETER_INVALIDETLCONTENT = 'InvalidParameter.InvalidEtlContent'
+
 # The same logset already exists.
 INVALIDPARAMETER_LOGSETCONFLICT = 'InvalidParameter.LogsetConflict'
 
@@ -215,6 +224,9 @@ OPERATIONDENIED_TOPICHASDATAFORMTASK = 'OperationDenied.TopicHasDataFormTask'
 # The topic is bound to a function for shipping.
 OPERATIONDENIED_TOPICHASDELIVERFUNCTION = 'OperationDenied.TopicHasDeliverFunction'
 
+# Unable to delete this topic because an external data source is configured for it.
+OPERATIONDENIED_TOPICHASEXTERNALDATASOURCECONFIG = 'OperationDenied.TopicHasExternalDatasourceConfig'
+
 # The topic is bound to the `scheduleSql` job.
 OPERATIONDENIED_TOPICHASSCHEDULESQLTASK = 'OperationDenied.TopicHasScheduleSqlTask'
 
