@@ -23,6 +23,9 @@ DRYRUNOPERATION = 'DryRunOperation'
 # Operation failed.
 FAILEDOPERATION = 'FailedOperation'
 
+# 
+FAILEDOPERATION_SEGMENTLOADING = 'FailedOperation.SegmentLoading'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
