@@ -23,9 +23,15 @@ FAILEDOPERATION = 'FailedOperation'
 # FailedOperation.MailIsRegistered
 FAILEDOPERATION_MAILISREGISTERED = 'FailedOperation.MailIsRegistered'
 
+# Invalid UIN
+FAILEDOPERATION_UININVALID = 'FailedOperation.UinInvalid'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
+# Invalid parameter
+INVALIDPARAMETER = 'InvalidParameter'
+
 # InvalidParameter.AccountTypeContentIncorrect
 INVALIDPARAMETER_ACCOUNTTYPECONTENTINCORRECT = 'InvalidParameter.AccountTypeContentIncorrect'
 
@@ -47,6 +53,9 @@ INVALIDPARAMETER_COUNTRYCODEFORMATINCORRECT = 'InvalidParameter.CountryCodeForma
 # InvalidParameter.MailFormatIncorrect
 INVALIDPARAMETER_MAILFORMATINCORRECT = 'InvalidParameter.MailFormatIncorrect'
 
+# 
+INVALIDPARAMETER_PAGE = 'InvalidParameter.Page'
+
 # InvalidParameter.PasswordContentIncorrect
 INVALIDPARAMETER_PASSWORDCONTENTINCORRECT = 'InvalidParameter.PasswordContentIncorrect'
 
@@ -68,6 +77,9 @@ INVALIDPARAMETERVALUE_AREAEMPTY = 'InvalidParameterValue.AreaEmpty'
 # InvalidParameterValue.CountryCodeEmpty
 INVALIDPARAMETERVALUE_COUNTRYCODEEMPTY = 'InvalidParameterValue.CountryCodeEmpty'
 
+# Incorrect month value
+INVALIDPARAMETERVALUE_INVALIDMONTH = 'InvalidParameterValue.InvalidMonth'
+
 # InvalidParameterValue.MailEmpty
 INVALIDPARAMETERVALUE_MAILEMPTY = 'InvalidParameterValue.MailEmpty'
 
@@ -77,6 +89,9 @@ INVALIDPARAMETERVALUE_PASSWORDEMPTY = 'InvalidParameterValue.PasswordEmpty'
 # InvalidParameterValue.PhoneNumEmpty
 INVALIDPARAMETERVALUE_PHONENUMEMPTY = 'InvalidParameterValue.PhoneNumEmpty'
 
+# Missing parameter
+MISSINGPARAMETER = 'MissingParameter'
+
 # Operation denied.
 OPERATIONDENIED = 'OperationDenied'
 
@@ -89,5 +104,11 @@ REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
 # Unauthorized operation.
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# The current user is not a customer.
+UNAUTHORIZEDOPERATION_NOTCUSTOMERUIN = 'UnauthorizedOperation.NotCustomerUin'
+
 # The current user doesn’t have permission for the operation.
 UNAUTHORIZEDOPERATION_UINNOAUTH = 'UnauthorizedOperation.UinNoAuth'
+
+# Unknown parameter
+UNKNOWNPARAMETER = 'UnknownParameter'
