@@ -993,6 +993,98 @@ class KmsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def PostQuantumCryptoDecrypt(self, request):
+        """u200dThis API u200dis used to decrypt ciphertext using post-quantum cryptography (PQC) algorithm, and return the plaintext.
+
+        :param request: Request instance for PostQuantumCryptoDecrypt.
+        :type request: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoDecryptRequest`
+        :rtype: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoDecryptResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("PostQuantumCryptoDecrypt", params, headers=headers)
+            response = json.loads(body)
+            model = models.PostQuantumCryptoDecryptResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def PostQuantumCryptoEncrypt(self, request):
+        """u200dThis API u200dis used to encrypt using PQC. It supports up to 4 KB of data. It is applicable for encryption of database passwords, RSA keys, or other sensitive information. You can also apply `DataKey` generated by API `GenerateDataKey` to encrypt or decrypt your local data.
+
+        :param request: Request instance for PostQuantumCryptoEncrypt.
+        :type request: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoEncryptRequest`
+        :rtype: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoEncryptResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("PostQuantumCryptoEncrypt", params, headers=headers)
+            response = json.loads(body)
+            model = models.PostQuantumCryptoEncryptResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def PostQuantumCryptoSign(self, request):
+        """This API is used to sign u200dusing PQC.
+
+        :param request: Request instance for PostQuantumCryptoSign.
+        :type request: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoSignRequest`
+        :rtype: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoSignResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("PostQuantumCryptoSign", params, headers=headers)
+            response = json.loads(body)
+            model = models.PostQuantumCryptoSignResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def PostQuantumCryptoVerify(self, request):
+        """This API is used to verify a signature u200dusing PQC.
+
+        :param request: Request instance for PostQuantumCryptoVerify.
+        :type request: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoVerifyRequest`
+        :rtype: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoVerifyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("PostQuantumCryptoVerify", params, headers=headers)
+            response = json.loads(body)
+            model = models.PostQuantumCryptoVerifyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ReEncrypt(self, request):
         """Re-encrypt the ciphertext using the specified CMK.
 
