@@ -44,15 +44,27 @@ FAILEDOPERATION_CANNOTGETORDER = 'FailedOperation.CannotGetOrder'
 # The certificate already exists.
 FAILEDOPERATION_CERTIFICATEEXISTS = 'FailedOperation.CertificateExists'
 
+# Unable to use the deployment feature because the login account is an internal account with too many instance resources. Please contact us to handle it.
+FAILEDOPERATION_CERTIFICATEHOSTRESOURCEINNERINTERRUPT = 'FailedOperation.CertificateHostResourceInnerInterrupt'
+
 # The certificate is invalid.
 FAILEDOPERATION_CERTIFICATEINVALID = 'FailedOperation.CertificateInvalid'
 
 # The certificate and the private key do not match.
 FAILEDOPERATION_CERTIFICATEMISMATCH = 'FailedOperation.CertificateMismatch'
 
+# The certificate is not available. Please check and try again.
+FAILEDOPERATION_CERTIFICATENOTAVAILABLE = 'FailedOperation.CertificateNotAvailable'
+
 # The certificate does not exist.
 FAILEDOPERATION_CERTIFICATENOTFOUND = 'FailedOperation.CertificateNotFound'
 
+# The certificate does not exist, or the review cannot be canceled.
+FAILEDOPERATION_CERTIFICATENOTFOUNDORCANTCANCEL = 'FailedOperation.CertificateNotFoundOrCantCancel'
+
+# You cannot re-submit a review application for a certificate in this status.
+FAILEDOPERATION_CERTIFICATESTATUSNOTALLOWRESUBMIT = 'FailedOperation.CertificateStatusNotAllowResubmit'
+
 # The confirmation letter file cannot exceed 1.4 MB.
 FAILEDOPERATION_CONFIRMLETTERTOOLARGE = 'FailedOperation.ConfirmLetterTooLarge'
 
@@ -104,6 +116,9 @@ FAILEDOPERATION_PACKAGECOUNTLIMIT = 'FailedOperation.PackageCountLimit'
 # The benefit package has expired.
 FAILEDOPERATION_PACKAGEEXPIRED = 'FailedOperation.PackageExpired'
 
+# The role does not exist. Please authorize the role first.
+FAILEDOPERATION_ROLENOTFOUNDAUTHORIZATION = 'FailedOperation.RoleNotFoundAuthorization'
+
 # A system error occurred.
 FAILEDOPERATION_SYSTEMERROR = 'FailedOperation.SystemError'
 
@@ -119,6 +134,12 @@ INTERNALERROR_BACKENDRESPONSEERROR = 'InternalError.BackendResponseError'
 # The parameter is incorrect.
 INVALIDPARAMETER = 'InvalidParameter'
 
+# u200cYou cannot re-submit a review application for a certificate in this status.
+INVALIDPARAMETER_CERTIFICATESTATUSNOTALLOWRESUBMIT = 'InvalidParameter.CertificateStatusNotAllowResubmit'
+
+# Incorrect CSR ID.
+INVALIDPARAMETER_INVALIDCSRID = 'InvalidParameter.InvalidCSRId'
+
 # The list of benefit point IDs is invalid.
 INVALIDPARAMETER_PACKAGEIDSINVALID = 'InvalidParameter.PackageIdsInvalid'
 
