@@ -20,6 +20,9 @@ AUTHFAILURE = 'AuthFailure'
 # Operation failed
 FAILEDOPERATION = 'FailedOperation'
 
+# Database error
+FAILEDOPERATION_DBERROR = 'FailedOperation.DbError'
+
 # Dependency exception.
 FAILEDOPERATION_DEPENDENCEERROR = 'FailedOperation.DependenceError'
 
@@ -50,6 +53,9 @@ FAILEDOPERATION_GETTCRCLIENT = 'FailedOperation.GetTcrClient'
 # The operation is canceled.
 FAILEDOPERATION_OPERATIONCANCEL = 'FailedOperation.OperationCancel'
 
+# 
+FAILEDOPERATION_PRECONDITIONFAILED = 'FailedOperation.PreconditionFailed'
+
 # The transaction failed.
 FAILEDOPERATION_TRADEFAILED = 'FailedOperation.TradeFailed'
 
